@@ -1,7 +1,6 @@
 # Pod::Text::Color -- Convert POD data to formatted color ASCII text
-# $Id: Color.pm,v 1.2 2001/11/15 08:04:18 eagle Exp $
 #
-# Copyright 1999, 2001 by Russ Allbery <rra@stanford.edu>
+# Copyright 1999, 2001, 2004, 2006 by Russ Allbery <rra@stanford.edu>
 #
 # This program is free software; you may redistribute it and/or modify it
 # under the same terms as Perl itself.
@@ -29,8 +28,7 @@ use vars qw(@ISA $VERSION);
 # Don't use the CVS revision as the version, since this module is also in Perl
 # core and too many things could munge CVS magic revision strings.  This
 # number should ideally be the same as the CVS revision in podlators, however.
-$VERSION = 1.02;
-
+$VERSION = 2.03;
 
 ##############################################################################
 # Overrides
@@ -38,24 +36,22 @@ $VERSION = 1.02;
 
 # Make level one headings bold.
 sub cmd_head1 {
-    my $self = shift;
-    local $_ = shift;
-    s/\s+$//;
-    $self->SUPER::cmd_head1 (colored ($_, 'bold'));
+    my ($self, $attrs, $text) = @_;
+    $text =~ s/\s+$//;
+    $self->SUPER::cmd_head1 ($attrs, colored ($text, 'bold'));
 }
 
 # Make level two headings bold.
 sub cmd_head2 {
-    my $self = shift;
-    local $_ = shift;
-    s/\s+$//;
-    $self->SUPER::cmd_head2 (colored ($_, 'bold'));
+    my ($self, $attrs, $text) = @_;
+    $text =~ s/\s+$//;
+    $self->SUPER::cmd_head2 ($attrs, colored ($text, 'bold'));
 }
 
-# Fix the various interior sequences.
-sub seq_b { return colored ($_[1], 'bold')   }
-sub seq_f { return colored ($_[1], 'cyan')   }
-sub seq_i { return colored ($_[1], 'yellow') }
+# Fix the various formatting codes.
+sub cmd_b { return colored ($_[2], 'bold')   }
+sub cmd_f { return colored ($_[2], 'cyan')   }
+sub cmd_i { return colored ($_[2], 'yellow') }
 
 # Output any included code in green.
 sub output_code {
@@ -71,10 +67,15 @@ sub wrap {
     local $_ = shift;
     my $output = '';
     my $spaces = ' ' x $$self{MARGIN};
-    my $width = $$self{width} - $$self{MARGIN};
+    my $width = $$self{opt_width} - $$self{MARGIN};
+
+    # We have to do $shortchar and $longchar in variables because the
+    # construct ${char}{0,$width} didn't do the right thing until Perl 5.8.x.
+    my $char = '(?:(?:\e\[[\d;]+m)*[^\n])';
+    my $shortchar = $char . "{0,$width}";
+    my $longchar = $char . "{$width}";
     while (length > $width) {
-        if (s/^((?:(?:\e\[[\d;]+m)?[^\n]){0,$width})\s+//
-            || s/^((?:(?:\e\[[\d;]+m)?[^\n]){$width})//) {
+        if (s/^($shortchar)\s+// || s/^($longchar)//) {
             $output .= $spaces . $1 . "\n";
         } else {
             last;
@@ -125,7 +126,11 @@ B<pod2text> should be taught about those.
 
 =head1 SEE ALSO
 
-L<Pod::Text>, L<Pod::Parser>
+L<Pod::Text>, L<Pod::Simple>
+
+The current version of this module is always available from its web site at
+L<http://www.eyrie.org/~eagle/software/podlators/>.  It is also part of the
+Perl core distribution as of 5.6.0.
 
 =head1 AUTHOR
 
@@ -133,7 +138,7 @@ Russ Allbery <rra@stanford.edu>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 1999, 2001 by Russ Allbery <rra@stanford.edu>.
+Copyright 1999, 2001, 2004, 2006 by Russ Allbery <rra@stanford.edu>.
 
 This program is free software; you may redistribute it and/or modify it
 under the same terms as Perl itself.
